import _withHandlers from "recompact/withHandlers";
import _isFunction from "lodash/isFunction";
import _pick from "lodash/pick";
import _noop from "lodash/noop";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet } from 'react-native';
import StylePropType from 'react-native-web-ui-components/StylePropType';
import RNTagInput from 'react-native-web-ui-components/TagInput';
const styles = StyleSheet.create({
  defaults: {
    marginBottom: 10
  },
  fullWidth: {
    width: '100%'
  },
  auto: {
    marginBottom: 0
  }
});
const allowedAttributes = ['hasError', 'value', 'readonly', 'disabled', 'secureTextEntry', 'placeholder', 'keyboardType', 'multiline', 'numberOfLines', 'onChange', 'onFocus', 'items', 'getItemValue', 'isMatch', 'text', 'tagStyle', 'inputStyle', 'allowNew', 'buildNew', 'Item', 'Menu', 'Tag', 'Input'];

const parseValue = (type, text) => {
  if (type === 'number' || type === 'integer') {
    return parseFloat(text);
  }

  return text;
};

const TagInputWidget = _withHandlers({
  onFocus: ({
    name,
    onFocus
  }) => () => onFocus(name),
  onChange: ({
    name,
    onChange
  }) => tags => onChange(tags, name),
  buildNew: ({
    schema,
    buildNew
  }) => text => {
    if (_isFunction(buildNew)) {
      return buildNew(text);
    }

    if (schema.items.type === 'object') {
      const [attribute] = Object.keys(schema.items.properties);
      const {
        type
      } = schema.items.properties[attribute];
      return {
        [attribute]: parseValue(type, text)
      };
    }

    return parseValue(schema.items.type, text);
  },
  getItemValue: ({
    schema,
    getItemValue
  }) => item => {
    if (_isFunction(getItemValue)) {
      return getItemValue(item);
    }

    if (schema.items.type === 'object') {
      const [attribute] = Object.keys(schema.items.properties);
      return item[attribute];
    }

    return item;
  }
})(({
  auto,
  name,
  focus,
  style,
  schema,
  uiSchema,
  ...props
}) => {
  if (schema.type !== 'array') {
    throw new Error('TagInputWidget can only be used with arrays.');
  }

  const currentStyle = [styles.defaults, auto ? styles.auto : styles.fullWidth, style];
  const focused = focus === name || focus === null && uiSchema['ui:autofocus'];
  return React.createElement(RNTagInput, _extends({}, _pick(props, allowedAttributes), {
    autoCapitalize: "none",
    className: "TagInput__widget",
    style: currentStyle,
    onSubmitEditing: _noop,
    autoFocus: focused,
    name: name
  }));
});

TagInputWidget.propTypes = {
  name: PropTypes.string.isRequired,
  onFocus: PropTypes.func.isRequired,
  onChange: PropTypes.func.isRequired,
  schema: PropTypes.shape().isRequired,
  uiSchema: PropTypes.shape().isRequired,
  buildNew: PropTypes.func,
  style: StylePropType,
  auto: PropTypes.bool,
  focus: PropTypes.string
};
TagInputWidget.defaultProps = {
  buildNew: null,
  style: null,
  auto: false,
  focus: null
};
export default TagInputWidget;